# Create real-time, fast 3D views of your quilts!

Got a Looking Glass? With Liquilt you can share them on the web in the fastest way possible! We convert your quilt into a specially crafted file to display them fast no matter what you run it on!

- Fast, web-components based library
- The tiniest 3D format
- Pre-computed, realtime rendering

# Demo

# How to get started

I assume you have pytrhob

- 